@@ -184,16 +184,6 @@ test_that('missing data', {
   expect_equal(f_pred, exp_f_pred)
 })
 
-# ------------------------------------------------------------------------------
-
-test_that('api errors', {
-  expect_error(
-    naive_Bayes() %>% set_engine("lda"),
-    regexp = "Available engines are: 'klaR', 'naivebayes'"
-  )
-})
-
-
 # ------------------------------------------------------------------------------
 
 test_that('printing', {
